#ifndef LIKNORM_H
#define LIKNORM_H

/** Major liknorm version. */
#define LIKNORM_VERSION_MAJOR 1
/** Minor liknorm version. */
#define LIKNORM_VERSION_MINOR 5
/** Minor liknorm version. */
#define LIKNORM_VERSION_PATCH 1
/** Liknorm version. */
#define LIKNORM_VERSION "1.5.1"

#ifdef __cplusplus
extern "C"
{
#endif

#include "liknorm/api.h"
#include "liknorm/platform.h"

#ifdef __cplusplus
}
#endif

#endif
