



if NOT exist %LIBRARY_INC%/liknorm.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if NOT exist %LIBRARY_LIB%/liknorm.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if NOT exist %LIBRARY_BIN%/liknorm.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if NOT exist %LIBRARY_LIB%/liknorm_static.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
